# SunPath

Interpolation and integration over sun path for applications in solar energy
 
[Solar Energy](https://www.journals.elsevier.com/solar-energy)


## Jupyter notebooks

"source/interpolation.ipynb"&emsp;<a href="https://mybinder.org/v2/gh/vg-cyi/SunPath.git/master?filepath=source%2Finterpolation.ipynb"><img src="https://mybinder.org/badge_logo.svg"/></a>

"."&emsp;<a href="https://mybinder.org/v2/gh/vg-cyi/SunPath.git/master"><img src="https://mybinder.org/badge_logo.svg"/></a>
